@@ -315,8 +315,8 @@ pub trait Context:
 }
 
 #[async_trait]
-pub trait ContextProvider<'a, T: Context> {
-    async fn new_context(&'a self) -> Result<T, Error>;
+pub trait ContextProvider<T: Context> {
+    async fn new_context(self) -> Result<T, Error>;
 }
 
 fn new_invalid_state_error(msg: &str) -> Error {
